from ..generic_extractors import *
from ..extractor_facebook import FacebookEvent
import json5
from bs4 import BeautifulSoup
import json
import os
from datetime import datetime

import logging

logger = logging.getLogger(__name__)


# A class dedicated to get events from a facebook events page
# such as https://www.facebook.com/laJeteeClermont/events
class CExtractor(TwoStepsExtractor):


    def build_event_url_list(self, content):
        soup = BeautifulSoup(content, "html.parser")

        debug = False

        found = False
        links = soup.find_all("a")
        for link in links:
            if link.get("href").startswith('https://www.facebook.com/events/'):
                self.add_event_url(link.get('href').split('?')[0])
                found = True

        if not found and debug:
            directory = "errors/"
            if not os.path.exists(directory):
                os.makedirs(directory)
            now = datetime.now()
            filename = directory + now.strftime("%Y%m%d_%H%M%S") + ".html"
            logger.warning("cannot find any event link in events page. Save content page in " + filename)
            with open(filename, "w") as text_file:
                text_file.write("<!-- " + self.url + " -->\n\n")
                text_file.write(content)

                


    def add_event_from_content(
        self,
        event_content,
        event_url,
        url_human=None,
        default_values=None,
        published=False,
    ):
        
        fevent = None
        soup = BeautifulSoup(event_content, "html.parser")
        for json_script in soup.find_all("script", type="application/json"):
            json_txt = json_script.get_text()
            json_struct = json.loads(json_txt)
            fevent = FacebookEvent.find_event_fragment_in_array(
                json_struct, fevent
            )

        if fevent is not None:
            for event in fevent.build_events(event_url):
                event["published"] = published

                self.add_event(default_values, **event)
        else:
            logger.warning("cannot find any event in page")


