from .downloader import *
from .extractor import *

import logging

logger = logging.getLogger(__name__)



class URL2Events:
    def __init__(
        self, downloader=SimpleDownloader(), extractor=None, single_event=False
    ):
        self.downloader = downloader
        self.extractor = extractor
        self.single_event = single_event

    def process(
        self, url, url_human=None, cache=None, default_values=None, published=False
    ):
        referer = ""
        if self.extractor:
            referer = self.extractor.url_referer
        content = self.downloader.get_content(url, cache, referer=referer)

        if content is None:
            return None

        if self.extractor is not None:
            self.extractor.set_downloader(self.downloader)
            return self.extractor.extract(
                content, url, url_human, default_values, published
            )
        else:
            # if the extractor is not defined, use a list of default extractors
            for e in Extractor.get_default_extractors(self.single_event):
                logger.warning('Extractor::' + type(e).__name__)
                e.set_downloader(self.downloader)
                events = e.extract(content, url, url_human, default_values, published)
                if events is not None and len(events) > 0:
                    return events
        return None
